@@ -188,7 +188,7 @@ class BaseCircuit:
             for name, value in self.constants.items():
                 elem = get_element_from_name(name)
                 units = check_and_eval(elem).units
-                if '_' in name:
+                if '_' in name and len(units) > 1:
                     unit = units[int(name.split('_')[-1])]
                 else:
                     unit = units[0]
